import { MarkerType_$type } from "igniteui-react-charts";
import { MarkerOutlineMode_$type } from "igniteui-react-charts";
import { MarkerFillMode_$type } from "igniteui-react-charts";
import { IgrGeographicMapSeriesHost } from "./igr-geographic-map-series-host";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
export class IgrGeographicMarkerSeries extends IgrGeographicMapSeriesHost {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.xf;
    }
    set markerType(v) {
        this.i.xf = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets thickness of the marker outline
    */
    get markerThickness() {
        return this.i.xg;
    }
    set markerThickness(v) {
        this.i.xg = +v;
    }
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    get markerOutlineMode() {
        return this.i.xe;
    }
    set markerOutlineMode(v) {
        this.i.xe = ensureEnum(MarkerOutlineMode_$type, v);
    }
    /**
     * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
    */
    get markerFillMode() {
        return this.i.xd;
    }
    set markerFillMode(v) {
        this.i.xd = ensureEnum(MarkerFillMode_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.xv;
    }
    set markerTemplate(v) {
        this.i.xv = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.x9);
    }
    set markerBrush(v) {
        this.i.x9 = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.ya);
    }
    set markerOutline(v) {
        this.i.ya = stringToBrush(v);
    }
    /**
     * Gets or sets the maximum number of markerItems displayed by the current series.
     * If more than the specified number of markerItems are visible, the series will automatically
     * choose a representative set.
    */
    get maximumMarkers() {
        return this.i.xh;
    }
    set maximumMarkers(v) {
        this.i.xh = +v;
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.xu;
    }
    set actualMarkerTemplate(v) {
        this.i.xu = v;
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.x7);
    }
    set actualMarkerBrush(v) {
        this.i.x7 = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.x8);
    }
    set actualMarkerOutline(v) {
        this.i.x8 = stringToBrush(v);
    }
}
