import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrSizeScale } from "igniteui-react-charts";
import { IgrBrushScale } from "igniteui-react-charts";
import { ScatterItemSearchMode_$type } from "igniteui-react-charts";
import { IgrAssigningScatterStyleEventArgs } from "igniteui-react-charts";
import { IgrAssigningScatterMarkerStyleEventArgs } from "igniteui-react-charts";
import { IgrGeographicMarkerSeries } from "./igr-geographic-marker-series";
import { GeographicProportionalSymbolSeries } from "./GeographicProportionalSymbolSeries";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export class IgrGeographicProportionalSymbolSeries extends IgrGeographicMarkerSeries {
    createImplementation() {
        return new GeographicProportionalSymbolSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._assigningScatterStyle = null;
        this._assigningScatterStyle_wrapped = null;
        this._assigningScatterMarkerStyle = null;
        this._assigningScatterMarkerStyle_wrapped = null;
    }
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers() {
        return this.i.ek;
    }
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    get latitudeMemberPath() {
        return this.i.y2;
    }
    set latitudeMemberPath(v) {
        this.i.y2 = v;
    }
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    get longitudeMemberPath() {
        return this.i.y4;
    }
    set longitudeMemberPath(v) {
        this.i.y4 = v;
    }
    /**
     * Gets or sets the radius mapping property for the current series object.
    */
    get radiusMemberPath() {
        return this.i.y9;
    }
    set radiusMemberPath(v) {
        this.i.y9 = v;
    }
    /**
     * Gets or sets the radius size scale for the bubbles.
    */
    get radiusScale() {
        const r = this.i.yg;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrSizeScale._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set radiusScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.yg = null : this.i.yg = v.i;
    }
    /**
     * Gets or sets the Label mapping property for the current series object.
    */
    get labelMemberPath() {
        return this.i.y0;
    }
    set labelMemberPath(v) {
        this.i.y0 = v;
    }
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    get fillMemberPath() {
        return this.i.ys;
    }
    set fillMemberPath(v) {
        this.i.ys = v;
    }
    /**
     * Gets or sets the brush scale for the marker brush.
    */
    get fillScale() {
        const r = this.i.yd;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrBrushScale._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set fillScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.yd = null : this.i.yd = v.i;
    }
    /**
     * Gets or sets the whether or not the FillScale uses global values of FillMemberPath of multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    get fillScaleUseGlobalValues() {
        return this.i.yk;
    }
    set fillScaleUseGlobalValues(v) {
        this.i.yk = ensureBool(v);
    }
    /**
     * Gets or sets whether or not the marker outline should use FillScale like the marker fill does.
     * This setting applies only if the current series has a FillScale set and it overrides MarkerOutline setting.
    */
    get markerOutlineUsesFillScale() {
        return this.i.yn;
    }
    set markerOutlineUsesFillScale(v) {
        this.i.yn = ensureBool(v);
    }
    /**
     * Gets or sets brightness of the marker outline. Using negative value will change marker outline to darker color and positive value will change marker outline to brighter color
     * Note you can use any values between minimum value of -1 (darkest outline) and maximum value of 1 (brightest outline)
    */
    get markerOutlineBrightness() {
        return this.i.yq;
    }
    set markerOutlineBrightness(v) {
        this.i.yq = +v;
    }
    /**
     * Gets or sets brightness of the marker fill. Using negative value will change marker fill to darker color and positive value will change marker fill to brighter color
     * Note you can use any values between minimum value of -1 (darkest fill) and maximum value of 1 (brightest fill)
    */
    get markerBrushBrightness() {
        return this.i.yp;
    }
    set markerBrushBrightness(v) {
        this.i.yp = +v;
    }
    /**
     * Gets or sets the whether or not the RadiusScale uses global values of RadiusMemberPath of multiple series.
     * This setting applies only if multiple series are using the same RadiusScale.
    */
    get radiusScaleUseGlobalValues() {
        return this.i.yo;
    }
    set radiusScaleUseGlobalValues(v) {
        this.i.yo = ensureBool(v);
    }
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
    */
    get isCustomScatterStyleAllowed() {
        return this.i.ym;
    }
    set isCustomScatterStyleAllowed(v) {
        this.i.ym = ensureBool(v);
    }
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomScatterMarkerStyleAllowed() {
        return this.i.yl;
    }
    set isCustomScatterMarkerStyleAllowed(v) {
        this.i.yl = ensureBool(v);
    }
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode() {
        return this.i.yf;
    }
    set itemSearchMode(v) {
        this.i.yf = ensureEnum(ScatterItemSearchMode_$type, v);
    }
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold() {
        return this.i.yr;
    }
    set itemSearchThreshold(v) {
        this.i.yr = +v;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.radiusScale && this.radiusScale.name && this.radiusScale.name == name) {
            return this.radiusScale;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.radiusScale && this.radiusScale._styling) {
            this.radiusScale._styling(container, component, this);
        }
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        this._inStyling = false;
    }
    /**
     * Event raised when Assigning Category Style
    */
    get assigningScatterStyle() {
        return this._assigningScatterStyle;
    }
    set assigningScatterStyle(ev) {
        if (this._assigningScatterStyle_wrapped !== null) {
            this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterStyle = null;
        }
        this._assigningScatterStyle = ev;
        this._assigningScatterStyle_wrapped = (o, e) => {
            let outerArgs = new IgrAssigningScatterStyleEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAssigningScatterStyle) {
                this.beforeAssigningScatterStyle(this, outerArgs);
            }
            if (this._assigningScatterStyle) {
                this._assigningScatterStyle(this, outerArgs);
            }
        };
        this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
        ;
    }
    /**
     * Event raised when Assigning Scatter Marker Style
    */
    get assigningScatterMarkerStyle() {
        return this._assigningScatterMarkerStyle;
    }
    set assigningScatterMarkerStyle(ev) {
        if (this._assigningScatterMarkerStyle_wrapped !== null) {
            this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            this._assigningScatterMarkerStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
        }
        this._assigningScatterMarkerStyle = ev;
        this._assigningScatterMarkerStyle_wrapped = (o, e) => {
            let outerArgs = new IgrAssigningScatterMarkerStyleEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAssigningScatterMarkerStyle) {
                this.beforeAssigningScatterMarkerStyle(this, outerArgs);
            }
            if (this._assigningScatterMarkerStyle) {
                this._assigningScatterMarkerStyle(this, outerArgs);
            }
        };
        this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
        ;
    }
}
