import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { MarkerType_$type } from "igniteui-react-charts";
import { MarkerOutlineMode_$type } from "igniteui-react-charts";
import { MarkerFillMode_$type } from "igniteui-react-charts";
import { CollisionAvoidanceType_$type } from "igniteui-react-charts";
import { IgrStyleShapeEventArgs } from "igniteui-react-charts";
import { IgrGeographicShapeSeriesBase } from "./igr-geographic-shape-series-base";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
import { Style } from "igniteui-react-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
export class IgrGeographicShapeSeries extends IgrGeographicShapeSeriesBase {
    createImplementation() {
        return new GeographicShapeSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._styleShape = null;
        this._styleShape_wrapped = null;
    }
    /**
     * Gets whether the current series shows a polygon shape.
    */
    get isPolygon() {
        return this.i.fr;
    }
    /**
     * Gets or sets the fill brush.
    */
    get shapeFill() {
        return this.i.zt ? this.i.zt.fill : null;
    }
    set shapeFill(v) {
        this.ensureShapeStyle();
        this.i.zt.fill = v;
    }
    /**
     * Gets or sets the stroke brush.
    */
    get shapeStroke() {
        return this.i.zt ? this.i.zt.stroke : null;
    }
    set shapeStroke(v) {
        this.ensureShapeStyle();
        this.i.zt.stroke = v;
    }
    /**
     * Gets or sets the stroke thickness.
    */
    get shapeStrokeThickness() {
        return this.i.zt ? this.i.zt.strokeThickness : NaN;
    }
    set shapeStrokeThickness(v) {
        this.ensureShapeStyle();
        this.i.zt.strokeThickness = +v;
    }
    /**
     * Gets or sets the opacity.
    */
    get shapeOpacity() {
        return this.i.zt ? this.i.zt.opacity : NaN;
    }
    set shapeOpacity(v) {
        this.ensureShapeStyle();
        this.i.zt.opacity = +v;
    }
    ensureShapeStyle() {
        if (this.i.zt) {
            return;
        }
        this.i.zt = new Style();
    }
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType() {
        return this.i.yn;
    }
    set markerType(v) {
        this.i.yn = ensureEnum(MarkerType_$type, v);
    }
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    get markerOutlineMode() {
        return this.i.ym;
    }
    set markerOutlineMode(v) {
        this.i.ym = ensureEnum(MarkerOutlineMode_$type, v);
    }
    /**
     * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
    */
    get markerFillMode() {
        return this.i.yl;
    }
    set markerFillMode(v) {
        this.i.yl = ensureEnum(MarkerFillMode_$type, v);
    }
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate() {
        return this.i.y9;
    }
    set markerTemplate(v) {
        this.i.y9 = v;
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush() {
        return brushToString(this.i.zq);
    }
    set markerBrush(v) {
        this.i.zq = stringToBrush(v);
    }
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline() {
        return brushToString(this.i.zr);
    }
    set markerOutline(v) {
        this.i.zr = stringToBrush(v);
    }
    /**
     * Gets or sets thickness of the marker outline
    */
    get markerThickness() {
        return this.i.yq;
    }
    set markerThickness(v) {
        this.i.yq = +v;
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance() {
        return this.i.yk;
    }
    set markerCollisionAvoidance(v) {
        this.i.yk = ensureEnum(CollisionAvoidanceType_$type, v);
    }
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate() {
        return this.i.y8;
    }
    set actualMarkerTemplate(v) {
        this.i.y8 = v;
    }
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush() {
        return brushToString(this.i.zo);
    }
    set actualMarkerBrush(v) {
        this.i.zo = stringToBrush(v);
    }
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline() {
        return brushToString(this.i.zp);
    }
    set actualMarkerOutline(v) {
        this.i.zp = stringToBrush(v);
    }
    get styleShape() {
        return this._styleShape;
    }
    set styleShape(ev) {
        if (this._styleShape_wrapped !== null) {
            this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
            this._styleShape_wrapped = null;
            this._styleShape = null;
        }
        this._styleShape = ev;
        this._styleShape_wrapped = (o, e) => {
            let outerArgs = new IgrStyleShapeEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeStyleShape) {
                this.beforeStyleShape(this, outerArgs);
            }
            if (this._styleShape) {
                this._styleShape(this, outerArgs);
            }
        };
        this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
        ;
    }
}
