import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { CollisionAvoidanceType_$type } from "igniteui-react-charts";
import { ScatterItemSearchMode_$type } from "igniteui-react-charts";
import { IgrAssigningScatterStyleEventArgs } from "igniteui-react-charts";
import { IgrAssigningScatterMarkerStyleEventArgs } from "igniteui-react-charts";
import { IgrGeographicMarkerSeries } from "./igr-geographic-marker-series";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
import { ensureBool, ensureEnum } from "igniteui-react-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export class IgrGeographicSymbolSeries extends IgrGeographicMarkerSeries {
    createImplementation() {
        return new GeographicSymbolSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._assigningScatterStyle = null;
        this._assigningScatterStyle_wrapped = null;
        this._assigningScatterMarkerStyle = null;
        this._assigningScatterMarkerStyle_wrapped = null;
    }
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers() {
        return this.i.ek;
    }
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    get latitudeMemberPath() {
        return this.i.yr;
    }
    set latitudeMemberPath(v) {
        this.i.yr = v;
    }
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    get longitudeMemberPath() {
        return this.i.yt;
    }
    set longitudeMemberPath(v) {
        this.i.yt = v;
    }
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance() {
        return this.i.yd;
    }
    set markerCollisionAvoidance(v) {
        this.i.yd = ensureEnum(CollisionAvoidanceType_$type, v);
    }
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
    */
    get isCustomScatterStyleAllowed() {
        return this.i.yk;
    }
    set isCustomScatterStyleAllowed(v) {
        this.i.yk = ensureBool(v);
    }
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomScatterMarkerStyleAllowed() {
        return this.i.yj;
    }
    set isCustomScatterMarkerStyleAllowed(v) {
        this.i.yj = ensureBool(v);
    }
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode() {
        return this.i.ye;
    }
    set itemSearchMode(v) {
        this.i.ye = ensureEnum(ScatterItemSearchMode_$type, v);
    }
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold() {
        return this.i.ym;
    }
    set itemSearchThreshold(v) {
        this.i.ym = +v;
    }
    /**
     * Event raised when Assigning Category Style
    */
    get assigningScatterStyle() {
        return this._assigningScatterStyle;
    }
    set assigningScatterStyle(ev) {
        if (this._assigningScatterStyle_wrapped !== null) {
            this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            this._assigningScatterStyle_wrapped = null;
            this._assigningScatterStyle = null;
        }
        this._assigningScatterStyle = ev;
        this._assigningScatterStyle_wrapped = (o, e) => {
            let outerArgs = new IgrAssigningScatterStyleEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAssigningScatterStyle) {
                this.beforeAssigningScatterStyle(this, outerArgs);
            }
            if (this._assigningScatterStyle) {
                this._assigningScatterStyle(this, outerArgs);
            }
        };
        this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
        ;
    }
    /**
     * Event raised when Assigning Scatter Marker Style
    */
    get assigningScatterMarkerStyle() {
        return this._assigningScatterMarkerStyle;
    }
    set assigningScatterMarkerStyle(ev) {
        if (this._assigningScatterMarkerStyle_wrapped !== null) {
            this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            this._assigningScatterMarkerStyle_wrapped = null;
            this._assigningScatterMarkerStyle = null;
        }
        this._assigningScatterMarkerStyle = ev;
        this._assigningScatterMarkerStyle_wrapped = (o, e) => {
            let outerArgs = new IgrAssigningScatterMarkerStyleEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeAssigningScatterMarkerStyle) {
                this.beforeAssigningScatterMarkerStyle(this, outerArgs);
            }
            if (this._assigningScatterMarkerStyle) {
                this._assigningScatterMarkerStyle(this, outerArgs);
            }
        };
        this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
        ;
    }
}
