import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrValueBrushScale } from "igniteui-react-charts";
import { IgrContourValueResolver } from "igniteui-react-charts";
import { IgrTriangulationStatusEventArgs } from "igniteui-react-core";
import { IgrGeographicXYTriangulatingSeries } from "./igr-geographic-xy-triangulating-series";
import { GeographicContourLineSeries } from "./GeographicContourLineSeries";
/**
 * Represents a class for Geographic Contour Series displayed on a map.
*/
var IgrGeographicContourLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicContourLineSeries, _super);
    function IgrGeographicContourLineSeries(props) {
        var _this = _super.call(this, props) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgrGeographicContourLineSeries.prototype.createImplementation = function () {
        return new GeographicContourLineSeries();
    };
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "isLineContour", {
        /**
         * Gets whether the current series shows a line contour shape.
        */
        get: function () {
            return this.i.fk;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "valueMemberPath", {
        /**
         * The name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get: function () {
            return this.i.x4;
        },
        set: function (v) {
            this.i.x4 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "fillScale", {
        /**
         * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get: function () {
            var r = this.i.x0;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrValueBrushScale._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.x0 = null : this.i.x0 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "actualFillScale", {
        /**
         * Gets actual fill scale that is set on the FillScale property or default FillScale
        */
        get: function () {
            var r = this.i.xz;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrValueBrushScale._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xz = null : this.i.xz = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "valueResolver", {
        /**
         * The ContourValueResolver used to determine the numeric values of contours.
        */
        get: function () {
            var r = this.i.xw;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrContourValueResolver._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xw = null : this.i.xw = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicContourLineSeries.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
            return this.actualFillScale;
        }
        if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
            return this.valueResolver;
        }
        return null;
    };
    IgrGeographicContourLineSeries.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.actualFillScale && this.actualFillScale._styling) {
            this.actualFillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    };
    Object.defineProperty(IgrGeographicContourLineSeries.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgrTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicContourLineSeries;
}(IgrGeographicXYTriangulatingSeries));
export { IgrGeographicContourLineSeries };
