import { __extends } from "tslib";
import { IgrSeries } from "igniteui-react-charts";
import { toPoint, fromPoint, fromRect } from "igniteui-react-core";
/**
 * Base class for hosting chart series in a IgxGeographicMap.Component
*/
var IgrGeographicMapSeriesHost = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicMapSeriesHost, _super);
    function IgrGeographicMapSeriesHost(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrGeographicMapSeriesHost.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMapSeriesHost.prototype, "isGeographic", {
        /**
         * Checks if this control is geographic coordinate system
        */
        get: function () {
            return this.i.fd;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMapSeriesHost.prototype, "hasMarkers", {
        /**
         * Gets whether this series supports markers
        */
        get: function () {
            return this.i.hasMarkers;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMapSeriesHost.prototype, "visibleFromScale", {
        /**
         * The minimum scale at which this series becomes visible.
         * The default value for this property is 1.0, which means the series will always be visible.  At a VisibleFromScale setting of 0.0, the series will never be visible.  At a VisibleFromScale setting of 0.5, the series will be visible as long as the map is zoomed in to at least 200%.
        */
        get: function () {
            return this.i.w7;
        },
        set: function (v) {
            this.i.w7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMapSeriesHost.prototype, "coercionMethods", {
        /**
         * Gets or sets the coercion methods to use when loading data from data sources.
         * Should be specified before setting any member paths, if being used. Setting it later
         * will not cause data to be reimported into the chart.
        */
        get: function () {
            return this.i.coercionMethods;
        },
        set: function (v) {
            this.i.coercionMethods = v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
    
    */
    IgrGeographicMapSeriesHost.prototype.notifyIndexedPropertiesChanged = function () {
        this.i.qi();
    };
    IgrGeographicMapSeriesHost.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.kr(item, memberPathName);
        return (iv);
    };
    /**
     * Gets the value of a requested member path from the series.
    
    * @param memberPathName  * The property name of a valid member path for the series
    */
    IgrGeographicMapSeriesHost.prototype.getMemberPathValue = function (memberPathName) {
        var iv = this.i.mf(memberPathName);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrGeographicMapSeriesHost.prototype.getItem = function (world) {
        var iv = this.i.ko(toPoint(world));
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getPreviousOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.kb(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getNextOrExactIndex = function (world, skipUnknowns) {
        var iv = this.i.j9(toPoint(world), skipUnknowns);
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i6(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.wh(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgrGeographicMapSeriesHost.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.ws(toPoint(world));
        return fromRect(iv);
    };
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    IgrGeographicMapSeriesHost.prototype.getSeriesValueMarkerBoundingBox = function (world) {
        var iv = this.i.wu(toPoint(world));
        return fromRect(iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesHighValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i2(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesHighValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.wd(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesLowValue = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.i4(toPoint(world), useInterpolation, skipUnknowns);
        return (iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesLowValuePosition = function (world, useInterpolation, skipUnknowns) {
        var iv = this.i.wf(toPoint(world), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesValuePositionFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.wi(toPoint(mouse), useInterpolation, skipUnknowns);
        return fromPoint(iv);
    };
    IgrGeographicMapSeriesHost.prototype.getSeriesValueFromSeriesPixel = function (mouse, useInterpolation, skipUnknowns) {
        var iv = this.i.i7(toPoint(mouse), useInterpolation, skipUnknowns);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrGeographicMapSeriesHost.prototype.getItemSpan = function () {
        var iv = this.i.ix();
        return (iv);
    };
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    */
    IgrGeographicMapSeriesHost.prototype.renderSeries = function (animate) {
        this.i.ru(animate);
    };
    /**
     * Called when this series' Style is updated.
    
    */
    IgrGeographicMapSeriesHost.prototype.styleUpdated = function () {
        this.i.sg();
    };
    return IgrGeographicMapSeriesHost;
}(IgrSeries));
export { IgrGeographicMapSeriesHost };
