import { __extends } from "tslib";
import { MarkerType_$type } from "igniteui-react-charts";
import { MarkerOutlineMode_$type } from "igniteui-react-charts";
import { MarkerFillMode_$type } from "igniteui-react-charts";
import { IgrGeographicMapSeriesHost } from "./igr-geographic-map-series-host";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
var IgrGeographicMarkerSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicMarkerSeries, _super);
    function IgrGeographicMarkerSeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = ensureEnum(MarkerType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerThickness", {
        /**
         * Gets or sets thickness of the marker outline
        */
        get: function () {
            return this.i.xg;
        },
        set: function (v) {
            this.i.xg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerOutlineMode", {
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = ensureEnum(MarkerOutlineMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerFillMode", {
        /**
         * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
        */
        get: function () {
            return this.i.xd;
        },
        set: function (v) {
            this.i.xd = ensureEnum(MarkerFillMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.xv;
        },
        set: function (v) {
            this.i.xv = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.x9);
        },
        set: function (v) {
            this.i.x9 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.ya);
        },
        set: function (v) {
            this.i.ya = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "maximumMarkers", {
        /**
         * Gets or sets the maximum number of markerItems displayed by the current series.
         * If more than the specified number of markerItems are visible, the series will automatically
         * choose a representative set.
        */
        get: function () {
            return this.i.xh;
        },
        set: function (v) {
            this.i.xh = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.xu;
        },
        set: function (v) {
            this.i.xu = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.x7);
        },
        set: function (v) {
            this.i.x7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicMarkerSeries.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.x8);
        },
        set: function (v) {
            this.i.x8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicMarkerSeries;
}(IgrGeographicMapSeriesHost));
export { IgrGeographicMarkerSeries };
