import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrColorScale } from "igniteui-react-charts";
import { IgrTriangulationStatusEventArgs } from "igniteui-react-core";
import { IgrGeographicXYTriangulatingSeries } from "./igr-geographic-xy-triangulating-series";
import { GeographicScatterAreaSeries } from "./GeographicScatterAreaSeries";
/**
 * Series class which draws a colored 2D surface, in a geographic context, based on a triangulation of XY data with numeric values assigned to each point.
*/
var IgrGeographicScatterAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicScatterAreaSeries, _super);
    function IgrGeographicScatterAreaSeries(props) {
        var _this = _super.call(this, props) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgrGeographicScatterAreaSeries.prototype.createImplementation = function () {
        return new GeographicScatterAreaSeries();
    };
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.ew;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "colorMemberPath", {
        /**
         * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
        */
        get: function () {
            return this.i.x3;
        },
        set: function (v) {
            this.i.x3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "colorScale", {
        /**
         * The ColorScale used to resolve the color values of points in the series.
        */
        get: function () {
            var r = this.i.xy;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrColorScale._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xy = null : this.i.xy = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "actualColorScale", {
        /**
         * Gets actual color scale that is set on ColorScale property or default ColorScale
        */
        get: function () {
            var r = this.i.xx;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrColorScale._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xx = null : this.i.xx = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicScatterAreaSeries.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.colorScale && this.colorScale.name && this.colorScale.name == name) {
            return this.colorScale;
        }
        if (this.actualColorScale && this.actualColorScale.name && this.actualColorScale.name == name) {
            return this.actualColorScale;
        }
        return null;
    };
    IgrGeographicScatterAreaSeries.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.colorScale && this.colorScale._styling) {
            this.colorScale._styling(container, component, this);
        }
        if (this.actualColorScale && this.actualColorScale._styling) {
            this.actualColorScale._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Updates ActualColorScale properties using HostedSeries's ColorScale properties
    
    */
    IgrGeographicScatterAreaSeries.prototype.updateActualColorScale = function () {
        this.i.x8();
    };
    Object.defineProperty(IgrGeographicScatterAreaSeries.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgrTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicScatterAreaSeries;
}(IgrGeographicXYTriangulatingSeries));
export { IgrGeographicScatterAreaSeries };
