import { __extends } from "tslib";
import { IgrGeographicMapSeriesHost } from "./igr-geographic-map-series-host";
import { IgrShapeDataSource } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ensureBool, ensureEnum } from "igniteui-react-core";
import { IgrAssigningShapeStyleEventArgs } from "igniteui-react-charts";
import { IgrAssigningShapeMarkerStyleEventArgs } from "igniteui-react-charts";
import { ShapeItemSearchMode_$type } from "igniteui-react-charts";
import { IgrBrushScale } from "igniteui-react-charts";
/**
 * Base class for series which render polygons on a map.
*/
var IgrGeographicShapeSeriesBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicShapeSeriesBase, _super);
    function IgrGeographicShapeSeriesBase(props) {
        var _this = _super.call(this, props) || this;
        _this._currData = null;
        _this._onImportCompleted = null;
        _this._assigningShapeStyle = null;
        _this._assigningShapeStyle_wrapped = null;
        _this._assigningShapeMarkerStyle = null;
        _this._assigningShapeMarkerStyle_wrapped = null;
        return _this;
    }
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "shapeDataSource", {
        get: function () {
            return this._shapeDataSource;
        },
        /**
         * Gets or sets the string path of the .shp portion of the Shapefile.
        */
        set: function (value) {
            this._shapeDataSource = value;
            this.updateShapeDataSource();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "databaseSource", {
        get: function () {
            return this._databaseSource;
        },
        /**
         * Gets or sets the string path of the .dbf portion of the Shapefile.
        */
        set: function (value) {
            this._databaseSource = value;
            this.updateShapeDataSource();
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicShapeSeriesBase.prototype.onUpdateDataSource = function (dataSource) {
        var _this = this;
        if (this._onImportCompleted == null) {
            this._onImportCompleted = function (s, e) {
                if (_this._currData) {
                    _this._currData.i.importCompleted = delegateRemove(_this._currData.i.importCompleted, _this._onImportCompleted);
                    var data = _this._currData;
                    _this._currData = null;
                    _this.i.itemsSource = data.getPointData();
                }
            };
        }
        if (dataSource && dataSource.getPointData) {
            if (dataSource.count > 0) {
                return dataSource.getPointData();
            }
            this._currData = dataSource;
            this._currData.i.importCompleted = delegateCombine(this._currData.i.importCompleted, this._onImportCompleted);
            return null;
        }
        return dataSource;
    };
    IgrGeographicShapeSeriesBase.prototype.updateShapeDataSource = function () {
        if (this._cachedShapeDataSource == null) {
            this._cachedShapeDataSource = new IgrShapeDataSource();
            this.onShapeDataSourceImportCompleted = this.onShapeDataSourceImportCompleted.bind(this);
            this._cachedShapeDataSource.importCompleted = this.onShapeDataSourceImportCompleted;
        }
        this._cachedShapeDataSource.shapefileSource = this._shapeDataSource;
        this._cachedShapeDataSource.databaseSource = this._databaseSource;
        if (this._shapeDataSource && this._databaseSource) {
            this._cachedShapeDataSource.dataBind();
        }
    };
    IgrGeographicShapeSeriesBase.prototype.onShapeDataSourceImportCompleted = function (s, e) {
        this.dataSource = this._cachedShapeDataSource.getPointData();
    };
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "shapeMemberPath", {
        /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
        get: function () {
            return this.i.x4;
        },
        set: function (v) {
            this.i.x4 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "isCustomShapeStyleAllowed", {
        /**
         * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
        */
        get: function () {
            return this.i.xp;
        },
        set: function (v) {
            this.i.xp = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "isCustomShapeMarkerStyleAllowed", {
        /**
         * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
        */
        get: function () {
            return this.i.xo;
        },
        set: function (v) {
            this.i.xo = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "itemSearchMode", {
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get: function () {
            return this.i.xg;
        },
        set: function (v) {
            this.i.xg = ensureEnum(ShapeItemSearchMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "itemSearchThreshold", {
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get: function () {
            return this.i.xs;
        },
        set: function (v) {
            this.i.xs = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "fillMemberPath", {
        /**
         * Gets or sets the fill mapping property for the current series object.
        */
        get: function () {
            return this.i.xt;
        },
        set: function (v) {
            this.i.xt = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "fillScale", {
        /**
         * Gets or sets the brush scale for the fill brush of markers.
        */
        get: function () {
            var r = this.i.xf;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrBrushScale._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xf = null : this.i.xf = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "fillScaleUseGlobalValues", {
        /**
         * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
         * This setting applies only if multiple series are using the same FillScale.
        */
        get: function () {
            return this.i.xn;
        },
        set: function (v) {
            this.i.xn = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "itemSearchPointsThreshold", {
        /**
         * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
        */
        get: function () {
            return this.i.xr;
        },
        set: function (v) {
            this.i.xr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "shapefileDataSource", {
        /**
         * Set a shapefile datasource to use with the series.
        */
        get: function () {
            var r = this.i.xj;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrShapeDataSource();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.xj = null : this.i.xj = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "shapeFilterResolution", {
        /**
         * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
         * In the case of GeographicPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
        */
        get: function () {
            return this.i.xq;
        },
        set: function (v) {
            this.i.xq = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicShapeSeriesBase.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.shapefileDataSource && this.shapefileDataSource.name && this.shapefileDataSource.name == name) {
            return this.shapefileDataSource;
        }
        return null;
    };
    IgrGeographicShapeSeriesBase.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        this._inStyling = false;
    };
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "assigningShapeStyle", {
        /**
         * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
        */
        get: function () {
            return this._assigningShapeStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningShapeStyle_wrapped !== null) {
                this.i.assigningShapeStyle = delegateRemove(this.i.assigningShapeStyle, this._assigningShapeStyle_wrapped);
                this._assigningShapeStyle_wrapped = null;
                this._assigningShapeStyle = null;
            }
            this._assigningShapeStyle = ev;
            this._assigningShapeStyle_wrapped = function (o, e) {
                var outerArgs = new IgrAssigningShapeStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningShapeStyle) {
                    _this.beforeAssigningShapeStyle(_this, outerArgs);
                }
                if (_this._assigningShapeStyle) {
                    _this._assigningShapeStyle(_this, outerArgs);
                }
            };
            this.i.assigningShapeStyle = delegateCombine(this.i.assigningShapeStyle, this._assigningShapeStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeriesBase.prototype, "assigningShapeMarkerStyle", {
        /**
         * Event raised when Assigning Shape Marker Style
        */
        get: function () {
            return this._assigningShapeMarkerStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningShapeMarkerStyle_wrapped !== null) {
                this.i.assigningShapeMarkerStyle = delegateRemove(this.i.assigningShapeMarkerStyle, this._assigningShapeMarkerStyle_wrapped);
                this._assigningShapeMarkerStyle_wrapped = null;
                this._assigningShapeMarkerStyle = null;
            }
            this._assigningShapeMarkerStyle = ev;
            this._assigningShapeMarkerStyle_wrapped = function (o, e) {
                var outerArgs = new IgrAssigningShapeMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningShapeMarkerStyle) {
                    _this.beforeAssigningShapeMarkerStyle(_this, outerArgs);
                }
                if (_this._assigningShapeMarkerStyle) {
                    _this._assigningShapeMarkerStyle(_this, outerArgs);
                }
            };
            this.i.assigningShapeMarkerStyle = delegateCombine(this.i.assigningShapeMarkerStyle, this._assigningShapeMarkerStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicShapeSeriesBase;
}(IgrGeographicMapSeriesHost));
export { IgrGeographicShapeSeriesBase };
