import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { MarkerType_$type } from "igniteui-react-charts";
import { MarkerOutlineMode_$type } from "igniteui-react-charts";
import { MarkerFillMode_$type } from "igniteui-react-charts";
import { CollisionAvoidanceType_$type } from "igniteui-react-charts";
import { IgrStyleShapeEventArgs } from "igniteui-react-charts";
import { IgrGeographicShapeSeriesBase } from "./igr-geographic-shape-series-base";
import { GeographicShapeSeries } from "./GeographicShapeSeries";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-react-core";
import { Style } from "igniteui-react-core";
/**
 * Series class which renders polygons as Paths, in a geographic context, based on lists of points in the ItemsSource.
*/
var IgrGeographicShapeSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicShapeSeries, _super);
    function IgrGeographicShapeSeries(props) {
        var _this = _super.call(this, props) || this;
        _this._styleShape = null;
        _this._styleShape_wrapped = null;
        return _this;
    }
    IgrGeographicShapeSeries.prototype.createImplementation = function () {
        return new GeographicShapeSeries();
    };
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "isPolygon", {
        /**
         * Gets whether the current series shows a polygon shape.
        */
        get: function () {
            return this.i.fr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "shapeFill", {
        /**
         * Gets or sets the fill brush.
        */
        get: function () {
            return this.i.zt ? this.i.zt.fill : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zt.fill = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "shapeStroke", {
        /**
         * Gets or sets the stroke brush.
        */
        get: function () {
            return this.i.zt ? this.i.zt.stroke : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zt.stroke = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "shapeStrokeThickness", {
        /**
         * Gets or sets the stroke thickness.
        */
        get: function () {
            return this.i.zt ? this.i.zt.strokeThickness : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zt.strokeThickness = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "shapeOpacity", {
        /**
         * Gets or sets the opacity.
        */
        get: function () {
            return this.i.zt ? this.i.zt.opacity : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.zt.opacity = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicShapeSeries.prototype.ensureShapeStyle = function () {
        if (this.i.zt) {
            return;
        }
        this.i.zt = new Style();
    };
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: function () {
            return this.i.yn;
        },
        set: function (v) {
            this.i.yn = ensureEnum(MarkerType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerOutlineMode", {
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get: function () {
            return this.i.ym;
        },
        set: function (v) {
            this.i.ym = ensureEnum(MarkerOutlineMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerFillMode", {
        /**
         * Gets or sets whether the marker brush is based on the marker outline of the series rather than the marker brushes collection.
        */
        get: function () {
            return this.i.yl;
        },
        set: function (v) {
            this.i.yl = ensureEnum(MarkerFillMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: function () {
            return this.i.y9;
        },
        set: function (v) {
            this.i.y9 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: function () {
            return brushToString(this.i.zq);
        },
        set: function (v) {
            this.i.zq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: function () {
            return brushToString(this.i.zr);
        },
        set: function (v) {
            this.i.zr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerThickness", {
        /**
         * Gets or sets thickness of the marker outline
        */
        get: function () {
            return this.i.yq;
        },
        set: function (v) {
            this.i.yq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: function () {
            return this.i.yk;
        },
        set: function (v) {
            this.i.yk = ensureEnum(CollisionAvoidanceType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: function () {
            return this.i.y8;
        },
        set: function (v) {
            this.i.y8 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: function () {
            return brushToString(this.i.zo);
        },
        set: function (v) {
            this.i.zo = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: function () {
            return brushToString(this.i.zp);
        },
        set: function (v) {
            this.i.zp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicShapeSeries.prototype, "styleShape", {
        get: function () {
            return this._styleShape;
        },
        set: function (ev) {
            var _this = this;
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = function (o, e) {
                var outerArgs = new IgrStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStyleShape) {
                    _this.beforeStyleShape(_this, outerArgs);
                }
                if (_this._styleShape) {
                    _this._styleShape(_this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicShapeSeries;
}(IgrGeographicShapeSeriesBase));
export { IgrGeographicShapeSeries };
