import { __extends } from "tslib";
import { IgrGeographicMapSeriesHost } from "./igr-geographic-map-series-host";
import { IgrTriangulationDataSource } from "igniteui-react-core";
/**
 * Base class for geographic series which triangulate XY data prior to rendering.
*/
var IgrGeographicXYTriangulatingSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrGeographicXYTriangulatingSeries, _super);
    function IgrGeographicXYTriangulatingSeries(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "triangulationDataSource", {
        get: function () {
            return this._triangulationDataSource;
        },
        /**
         * Gets or sets the string path specifying the location of the Itf file.
        */
        set: function (value) {
            this._triangulationDataSource = value;
            this.updateTriangulationDataSource();
        },
        enumerable: false,
        configurable: true
    });
    IgrGeographicXYTriangulatingSeries.prototype.updateTriangulationDataSource = function () {
        if (this._cachedTriangulationDataSource == null) {
            this._cachedTriangulationDataSource = new IgrTriangulationDataSource();
            this.onTriangulationDataSourceImportCompleted = this.onTriangulationDataSourceImportCompleted.bind(this);
            this._cachedTriangulationDataSource.importCompleted = this.onTriangulationDataSourceImportCompleted;
        }
        this._cachedTriangulationDataSource.source = this._triangulationDataSource;
    };
    IgrGeographicXYTriangulatingSeries.prototype.onTriangulationDataSourceImportCompleted = function (s, e) {
        this.dataSource = this._cachedTriangulationDataSource.getPointData();
        this.trianglesSource = this._cachedTriangulationDataSource.getTriangleData();
    };
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "longitudeMemberPath", {
        /**
     * The name of the property from which to extract the Longitude for each item in the ItemsSource.
    */
        get: function () {
            return this.i.xh;
        },
        set: function (v) {
            this.i.xh = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "latitudeMemberPath", {
        /**
         * The name of the property from which to extract the Latitude for each item in the ItemsSource.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "trianglesSource", {
        /**
         * The source of triangulation data.
         * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "triangleVertexMemberPath1", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.xk;
        },
        set: function (v) {
            this.i.xk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "triangleVertexMemberPath2", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.xm;
        },
        set: function (v) {
            this.i.xm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrGeographicXYTriangulatingSeries.prototype, "triangleVertexMemberPath3", {
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
        */
        get: function () {
            return this.i.xo;
        },
        set: function (v) {
            this.i.xo = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrGeographicXYTriangulatingSeries;
}(IgrGeographicMapSeriesHost));
export { IgrGeographicXYTriangulatingSeries };
