import { IgrValueBrushScale } from "igniteui-react-charts";
import { IgrContourValueResolver } from "igniteui-react-charts";
import { IgrTriangulationStatusEventArgs } from "igniteui-react-core";
import { IgrGeographicXYTriangulatingSeries, IIgrGeographicXYTriangulatingSeriesProps } from "./igr-geographic-xy-triangulating-series";
import { GeographicContourLineSeries } from "./GeographicContourLineSeries";
/**
 * Represents a class for Geographic Contour Series displayed on a map.
*/
export declare class IgrGeographicContourLineSeries extends IgrGeographicXYTriangulatingSeries<IIgrGeographicContourLineSeriesProps> {
    protected createImplementation(): GeographicContourLineSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicContourLineSeries;
    constructor(props: IIgrGeographicContourLineSeriesProps);
    /**
     * Gets whether the current series shows a line contour shape.
    */
    get isLineContour(): boolean;
    /**
     * The name of the property from which to retrieve the numeric values from the ItemsSource items.
    */
    get valueMemberPath(): string;
    set valueMemberPath(v: string);
    /**
     * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
    */
    get fillScale(): IgrValueBrushScale;
    set fillScale(v: IgrValueBrushScale);
    /**
     * Gets actual fill scale that is set on the FillScale property or default FillScale
    */
    get actualFillScale(): IgrValueBrushScale;
    set actualFillScale(v: IgrValueBrushScale);
    /**
     * The ContourValueResolver used to determine the numeric values of contours.
    */
    get valueResolver(): IgrContourValueResolver;
    set valueResolver(v: IgrContourValueResolver);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    private _triangulationStatusChanged;
    private _triangulationStatusChanged_wrapped;
    /**
     * Raised when the status of an ongoing Triangulation has changed.
    */
    get triangulationStatusChanged(): (s: IgrGeographicContourLineSeries, e: IgrTriangulationStatusEventArgs) => void;
    set triangulationStatusChanged(ev: (s: IgrGeographicContourLineSeries, e: IgrTriangulationStatusEventArgs) => void);
}
export interface IIgrGeographicContourLineSeriesProps extends IIgrGeographicXYTriangulatingSeriesProps {
    /**
     * The name of the property from which to retrieve the numeric values from the ItemsSource items.
    */
    valueMemberPath?: string;
    /**
     * The ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
    */
    fillScale?: IgrValueBrushScale;
    /**
     * Gets actual fill scale that is set on the FillScale property or default FillScale
    */
    actualFillScale?: IgrValueBrushScale;
    /**
     * The ContourValueResolver used to determine the numeric values of contours.
    */
    valueResolver?: IgrContourValueResolver;
    /**
     * Raised when the status of an ongoing Triangulation has changed.
    */
    triangulationStatusChanged?: (s: IgrGeographicContourLineSeries, e: IgrTriangulationStatusEventArgs) => void;
}
