import { IgrProgressiveLoadStatusEventArgs } from "igniteui-react-charts";
import { IgrGeographicMapSeriesHost, IIgrGeographicMapSeriesHostProps } from "./igr-geographic-map-series-host";
import { GeographicHighDensityScatterSeries } from "./GeographicHighDensityScatterSeries";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a HighDensityScatterSeries.
*/
export declare class IgrGeographicHighDensityScatterSeries extends IgrGeographicMapSeriesHost<IIgrGeographicHighDensityScatterSeriesProps> {
    protected createImplementation(): GeographicHighDensityScatterSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicHighDensityScatterSeries;
    constructor(props: IIgrGeographicHighDensityScatterSeriesProps);
    /**
     * Gets whether the current series shows pixels.
    */
    get isPixel(): boolean;
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    get latitudeMemberPath(): string;
    set latitudeMemberPath(v: string);
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    get longitudeMemberPath(): string;
    set longitudeMemberPath(v: string);
    /**
     * Gets or sets the whether to use use brute force mode.
    */
    get useBruteForce(): boolean;
    set useBruteForce(v: boolean);
    /**
     * Gets or sets the whether to progressively load the data into the chart.
    */
    get progressiveLoad(): boolean;
    set progressiveLoad(v: boolean);
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    get mouseOverEnabled(): boolean;
    set mouseOverEnabled(v: boolean);
    /**
     * Gets or sets the density value that maps to the minimum heat color.
    */
    get heatMinimum(): number;
    set heatMinimum(v: number);
    /**
     * Gets or sets the value that maps to the maximum heat color.
    */
    get heatMaximum(): number;
    set heatMaximum(v: number);
    /**
     * Gets or sets the color to use for the minimum end of the scale.
    */
    get heatMinimumColor(): string;
    set heatMinimumColor(v: string);
    /**
     * Gets or sets the color to use for the maximum end of the scale.
    */
    get heatMaximumColor(): string;
    set heatMaximumColor(v: string);
    /**
     * Gets or sets the the pixel extent of the square data points that are rendered.
    */
    get pointExtent(): number;
    set pointExtent(v: number);
    /**
     * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
    */
    get progressiveStatus(): number;
    set progressiveStatus(v: number);
    private _progressiveLoadStatusChanged;
    private _progressiveLoadStatusChanged_wrapped;
    /**
     * Raised when the progressive loading state of the series has changed.
    */
    get progressiveLoadStatusChanged(): (s: IgrGeographicHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void;
    set progressiveLoadStatusChanged(ev: (s: IgrGeographicHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void);
}
export interface IIgrGeographicHighDensityScatterSeriesProps extends IIgrGeographicMapSeriesHostProps {
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    latitudeMemberPath?: string;
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    longitudeMemberPath?: string;
    /**
     * Gets or sets the whether to use use brute force mode.
    */
    useBruteForce?: boolean | string;
    /**
     * Gets or sets the whether to progressively load the data into the chart.
    */
    progressiveLoad?: boolean | string;
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    mouseOverEnabled?: boolean | string;
    /**
     * Gets or sets the density value that maps to the minimum heat color.
    */
    heatMinimum?: number | string;
    /**
     * Gets or sets the value that maps to the maximum heat color.
    */
    heatMaximum?: number | string;
    /**
     * Gets or sets the color to use for the minimum end of the scale.
    */
    heatMinimumColor?: string;
    /**
     * Gets or sets the color to use for the maximum end of the scale.
    */
    heatMaximumColor?: string;
    /**
     * Gets or sets the the pixel extent of the square data points that are rendered.
    */
    pointExtent?: number | string;
    /**
     * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
    */
    progressiveStatus?: number | string;
    /**
     * Raised when the progressive loading state of the series has changed.
    */
    progressiveLoadStatusChanged?: (s: IgrGeographicHighDensityScatterSeries, e: IgrProgressiveLoadStatusEventArgs) => void;
}
