import { IgDataTemplate } from "igniteui-react-core";
import { MarkerType } from "igniteui-react-charts";
import { MarkerOutlineMode } from "igniteui-react-charts";
import { MarkerFillMode } from "igniteui-react-charts";
import { IgrGeographicMapSeriesHost, IIgrGeographicMapSeriesHostProps } from "./igr-geographic-map-series-host";
import { GeographicMarkerSeries } from "./GeographicMarkerSeries";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
export declare abstract class IgrGeographicMarkerSeries<P extends IIgrGeographicMarkerSeriesProps = IIgrGeographicMarkerSeriesProps> extends IgrGeographicMapSeriesHost<P> {
    /**
                                 * @hidden
                                 */
    get i(): GeographicMarkerSeries;
    constructor(props: P);
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    get markerType(): MarkerType;
    set markerType(v: MarkerType);
    /**
     * Gets or sets thickness of the marker outline
    */
    get markerThickness(): number;
    set markerThickness(v: number);
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    get markerOutlineMode(): MarkerOutlineMode;
    set markerOutlineMode(v: MarkerOutlineMode);
    /**
     * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
    */
    get markerFillMode(): MarkerFillMode;
    set markerFillMode(v: MarkerFillMode);
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    get markerTemplate(): IgDataTemplate;
    set markerTemplate(v: IgDataTemplate);
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    get markerBrush(): string;
    set markerBrush(v: string);
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    get markerOutline(): string;
    set markerOutline(v: string);
    /**
     * Gets or sets the maximum number of markerItems displayed by the current series.
     * If more than the specified number of markerItems are visible, the series will automatically
     * choose a representative set.
    */
    get maximumMarkers(): number;
    set maximumMarkers(v: number);
    /**
     * Gets the effective marker template for the current series object.
    */
    get actualMarkerTemplate(): IgDataTemplate;
    set actualMarkerTemplate(v: IgDataTemplate);
    /**
     * Gets the effective marker brush for the current series object.
    */
    get actualMarkerBrush(): string;
    set actualMarkerBrush(v: string);
    /**
     * Gets the effective marker outline for the current series object.
    */
    get actualMarkerOutline(): string;
    set actualMarkerOutline(v: string);
}
export interface IIgrGeographicMarkerSeriesProps extends IIgrGeographicMapSeriesHostProps {
    /**
     * Gets or sets the marker type for the current series object.
     * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
    */
    markerType?: MarkerType | string;
    /**
     * Gets or sets thickness of the marker outline
    */
    markerThickness?: number | string;
    /**
     * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
    */
    markerOutlineMode?: MarkerOutlineMode | string;
    /**
     * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
    */
    markerFillMode?: MarkerFillMode | string;
    /**
     * Gets or sets the MarkerTemplate for the current series object.
    */
    markerTemplate?: IgDataTemplate;
    /**
     * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
    */
    markerBrush?: string;
    /**
     * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
    */
    markerOutline?: string;
    /**
     * Gets or sets the maximum number of markerItems displayed by the current series.
     * If more than the specified number of markerItems are visible, the series will automatically
     * choose a representative set.
    */
    maximumMarkers?: number | string;
    /**
     * Gets the effective marker template for the current series object.
    */
    actualMarkerTemplate?: IgDataTemplate;
    /**
     * Gets the effective marker brush for the current series object.
    */
    actualMarkerBrush?: string;
    /**
     * Gets the effective marker outline for the current series object.
    */
    actualMarkerOutline?: string;
}
