import { IgrColorScale } from "igniteui-react-charts";
import { IgrTriangulationStatusEventArgs } from "igniteui-react-core";
import { IgrGeographicXYTriangulatingSeries, IIgrGeographicXYTriangulatingSeriesProps } from "./igr-geographic-xy-triangulating-series";
import { GeographicScatterAreaSeries } from "./GeographicScatterAreaSeries";
/**
 * Series class which draws a colored 2D surface, in a geographic context, based on a triangulation of XY data with numeric values assigned to each point.
*/
export declare class IgrGeographicScatterAreaSeries extends IgrGeographicXYTriangulatingSeries<IIgrGeographicScatterAreaSeriesProps> {
    protected createImplementation(): GeographicScatterAreaSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicScatterAreaSeries;
    constructor(props: IIgrGeographicScatterAreaSeriesProps);
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea(): boolean;
    /**
     * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
    */
    get colorMemberPath(): string;
    set colorMemberPath(v: string);
    /**
     * The ColorScale used to resolve the color values of points in the series.
    */
    get colorScale(): IgrColorScale;
    set colorScale(v: IgrColorScale);
    /**
     * Gets actual color scale that is set on ColorScale property or default ColorScale
    */
    get actualColorScale(): IgrColorScale;
    set actualColorScale(v: IgrColorScale);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Updates ActualColorScale properties using HostedSeries's ColorScale properties
    
    */
    updateActualColorScale(): void;
    private _triangulationStatusChanged;
    private _triangulationStatusChanged_wrapped;
    /**
     * Raised when the status of an ongoing Triangulation has changed.
    */
    get triangulationStatusChanged(): (s: IgrGeographicScatterAreaSeries, e: IgrTriangulationStatusEventArgs) => void;
    set triangulationStatusChanged(ev: (s: IgrGeographicScatterAreaSeries, e: IgrTriangulationStatusEventArgs) => void);
}
export interface IIgrGeographicScatterAreaSeriesProps extends IIgrGeographicXYTriangulatingSeriesProps {
    /**
     * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
    */
    colorMemberPath?: string;
    /**
     * The ColorScale used to resolve the color values of points in the series.
    */
    colorScale?: IgrColorScale;
    /**
     * Gets actual color scale that is set on ColorScale property or default ColorScale
    */
    actualColorScale?: IgrColorScale;
    /**
     * Raised when the status of an ongoing Triangulation has changed.
    */
    triangulationStatusChanged?: (s: IgrGeographicScatterAreaSeries, e: IgrTriangulationStatusEventArgs) => void;
}
