import { IgrGeographicMapSeriesHost, IIgrGeographicMapSeriesHostProps } from "./igr-geographic-map-series-host";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { IgrShapeDataSource } from "igniteui-react-core";
import { IgrAssigningShapeStyleEventArgs } from "igniteui-react-charts";
import { IgrAssigningShapeMarkerStyleEventArgs } from "igniteui-react-charts";
import { ShapeItemSearchMode } from "igniteui-react-charts";
import { IgrBrushScale } from "igniteui-react-charts";
/**
 * Base class for series which render polygons on a map.
*/
export declare abstract class IgrGeographicShapeSeriesBase<P extends IIgrGeographicShapeSeriesBaseProps = IIgrGeographicShapeSeriesBaseProps> extends IgrGeographicMapSeriesHost<P> {
    get i(): GeographicShapeSeriesBase;
    constructor(props: P);
    private _shapeDataSource;
    /**
     * Gets or sets the string path of the .shp portion of the Shapefile.
    */
    set shapeDataSource(value: string);
    get shapeDataSource(): string;
    private _databaseSource;
    /**
     * Gets or sets the string path of the .dbf portion of the Shapefile.
    */
    set databaseSource(value: string);
    get databaseSource(): string;
    private _currData;
    private _onImportCompleted;
    protected onUpdateDataSource(dataSource: any): any;
    private _cachedShapeDataSource;
    private updateShapeDataSource;
    private onShapeDataSourceImportCompleted;
    /**
 * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
 * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
*/
    get shapeMemberPath(): string;
    set shapeMemberPath(v: string);
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
    */
    get isCustomShapeStyleAllowed(): boolean;
    set isCustomShapeStyleAllowed(v: boolean);
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomShapeMarkerStyleAllowed(): boolean;
    set isCustomShapeMarkerStyleAllowed(v: boolean);
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode(): ShapeItemSearchMode;
    set itemSearchMode(v: ShapeItemSearchMode);
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold(): number;
    set itemSearchThreshold(v: number);
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    get fillMemberPath(): string;
    set fillMemberPath(v: string);
    /**
     * Gets or sets the brush scale for the fill brush of markers.
    */
    get fillScale(): IgrBrushScale;
    set fillScale(v: IgrBrushScale);
    /**
     * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    get fillScaleUseGlobalValues(): boolean;
    set fillScaleUseGlobalValues(v: boolean);
    /**
     * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchPointsThreshold(): number;
    set itemSearchPointsThreshold(v: number);
    /**
     * Set a shapefile datasource to use with the series.
    */
    get shapefileDataSource(): IgrShapeDataSource;
    set shapefileDataSource(v: IgrShapeDataSource);
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of GeographicPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    get shapeFilterResolution(): number;
    set shapeFilterResolution(v: number);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    private _assigningShapeStyle;
    private _assigningShapeStyle_wrapped;
    /**
     * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
    */
    get assigningShapeStyle(): (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeStyleEventArgs) => void;
    set assigningShapeStyle(ev: (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeStyleEventArgs) => void);
    private _assigningShapeMarkerStyle;
    private _assigningShapeMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Shape Marker Style
    */
    get assigningShapeMarkerStyle(): (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeMarkerStyleEventArgs) => void;
    set assigningShapeMarkerStyle(ev: (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeMarkerStyleEventArgs) => void);
}
export interface IIgrGeographicShapeSeriesBaseProps extends IIgrGeographicMapSeriesHostProps {
    /**
     * Gets or sets the string path of the .shp portion of the Shapefile.
    */
    shapeDataSource?: string;
    /**
     * Gets or sets the string path of the ..dbf portion of the Shapefile.
    */
    databaseSource?: string;
    /**
 * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
 * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
*/
    shapeMemberPath?: string;
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual visuals.
    */
    isCustomShapeStyleAllowed?: boolean | string;
    /**
     * Gets or sets whether this Shape series should allow custom style overrides of its individual marker visuals.
    */
    isCustomShapeMarkerStyleAllowed?: boolean | string;
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    itemSearchMode?: ShapeItemSearchMode | string;
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    itemSearchThreshold?: number | string;
    /**
     * Gets or sets the fill mapping property for the current series object.
    */
    fillMemberPath?: string;
    /**
     * Gets or sets the brush scale for the fill brush of markers.
    */
    fillScale?: IgrBrushScale;
    /**
     * Gets or sets whether or not the FillScale uses global min/max values of FillMemberPath from multiple series.
     * This setting applies only if multiple series are using the same FillScale.
    */
    fillScaleUseGlobalValues?: boolean | string;
    /**
     * Gets or sets the points threshold to use when searching for items using ItemSearchMode.
    */
    itemSearchPointsThreshold?: number | string;
    /**
     * Set a shapefile datasource to use with the series.
    */
    shapefileDataSource?: IgrShapeDataSource;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of GeographicPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution?: number | string;
    /**
 * Event raised when Assigning Shape Style. Note, if using this event, or highlighting, its best to avoid use of ShapeStyle/StyleShape/ShapeStyleSelector.
*/
    assigningShapeStyle?: (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeStyleEventArgs) => void;
    /**
     * Event raised when Assigning Shape Marker Style
    */
    assigningShapeMarkerStyle?: (s: IgrGeographicShapeSeriesBase, e: IgrAssigningShapeMarkerStyleEventArgs) => void;
}
