import { CollisionAvoidanceType } from "igniteui-react-charts";
import { ScatterItemSearchMode } from "igniteui-react-charts";
import { IgrAssigningScatterStyleEventArgs } from "igniteui-react-charts";
import { IgrAssigningScatterMarkerStyleEventArgs } from "igniteui-react-charts";
import { IgrGeographicMarkerSeries, IIgrGeographicMarkerSeriesProps } from "./igr-geographic-marker-series";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
export declare class IgrGeographicSymbolSeries extends IgrGeographicMarkerSeries<IIgrGeographicSymbolSeriesProps> {
    protected createImplementation(): GeographicSymbolSeries;
    /**
                                 * @hidden
                                 */
    get i(): GeographicSymbolSeries;
    constructor(props: IIgrGeographicSymbolSeriesProps);
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers(): boolean;
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    get latitudeMemberPath(): string;
    set latitudeMemberPath(v: string);
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    get longitudeMemberPath(): string;
    set longitudeMemberPath(v: string);
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    get markerCollisionAvoidance(): CollisionAvoidanceType;
    set markerCollisionAvoidance(v: CollisionAvoidanceType);
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
    */
    get isCustomScatterStyleAllowed(): boolean;
    set isCustomScatterStyleAllowed(v: boolean);
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomScatterMarkerStyleAllowed(): boolean;
    set isCustomScatterMarkerStyleAllowed(v: boolean);
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    get itemSearchMode(): ScatterItemSearchMode;
    set itemSearchMode(v: ScatterItemSearchMode);
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    get itemSearchThreshold(): number;
    set itemSearchThreshold(v: number);
    private _assigningScatterStyle;
    private _assigningScatterStyle_wrapped;
    /**
     * Event raised when Assigning Category Style
    */
    get assigningScatterStyle(): (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterStyleEventArgs) => void;
    set assigningScatterStyle(ev: (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterStyleEventArgs) => void);
    private _assigningScatterMarkerStyle;
    private _assigningScatterMarkerStyle_wrapped;
    /**
     * Event raised when Assigning Scatter Marker Style
    */
    get assigningScatterMarkerStyle(): (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterMarkerStyleEventArgs) => void;
    set assigningScatterMarkerStyle(ev: (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterMarkerStyleEventArgs) => void);
}
export interface IIgrGeographicSymbolSeriesProps extends IIgrGeographicMarkerSeriesProps {
    /**
     * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
    */
    latitudeMemberPath?: string;
    /**
     * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
    */
    longitudeMemberPath?: string;
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    markerCollisionAvoidance?: CollisionAvoidanceType | string;
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
    */
    isCustomScatterStyleAllowed?: boolean | string;
    /**
     * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
    */
    isCustomScatterMarkerStyleAllowed?: boolean | string;
    /**
     * Gets or sets the mode the series will use to find the closest point to the cursor.
    */
    itemSearchMode?: ScatterItemSearchMode | string;
    /**
     * Gets or sets the threshold to use when searching for items using ItemSearchMode.
    */
    itemSearchThreshold?: number | string;
    /**
     * Event raised when Assigning Category Style
    */
    assigningScatterStyle?: (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterStyleEventArgs) => void;
    /**
     * Event raised when Assigning Scatter Marker Style
    */
    assigningScatterMarkerStyle?: (s: IgrGeographicSymbolSeries, e: IgrAssigningScatterMarkerStyleEventArgs) => void;
}
