import { IgrGeographicMapSeriesHost, IIgrGeographicMapSeriesHostProps } from "./igr-geographic-map-series-host";
import { GeographicXYTriangulatingSeries } from "./GeographicXYTriangulatingSeries";
/**
 * Base class for geographic series which triangulate XY data prior to rendering.
*/
export declare abstract class IgrGeographicXYTriangulatingSeries<P extends IIgrGeographicXYTriangulatingSeriesProps = IIgrGeographicXYTriangulatingSeriesProps> extends IgrGeographicMapSeriesHost<P> {
    get i(): GeographicXYTriangulatingSeries;
    constructor(props: P);
    private _triangulationDataSource;
    /**
     * Gets or sets the string path specifying the location of the Itf file.
    */
    set triangulationDataSource(value: string);
    get triangulationDataSource(): string;
    private _cachedTriangulationDataSource;
    private updateTriangulationDataSource;
    private onTriangulationDataSourceImportCompleted;
    /**
 * The name of the property from which to extract the Longitude for each item in the ItemsSource.
*/
    get longitudeMemberPath(): string;
    set longitudeMemberPath(v: string);
    /**
     * The name of the property from which to extract the Latitude for each item in the ItemsSource.
    */
    get latitudeMemberPath(): string;
    set latitudeMemberPath(v: string);
    /**
     * The source of triangulation data.
     * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
    */
    get trianglesSource(): any[];
    set trianglesSource(v: any[]);
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
    */
    get triangleVertexMemberPath1(): string;
    set triangleVertexMemberPath1(v: string);
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
    */
    get triangleVertexMemberPath2(): string;
    set triangleVertexMemberPath2(v: string);
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
    */
    get triangleVertexMemberPath3(): string;
    set triangleVertexMemberPath3(v: string);
}
export interface IIgrGeographicXYTriangulatingSeriesProps extends IIgrGeographicMapSeriesHostProps {
    /**
    * Gets or sets the string path specifying the location of the Itf file.
    */
    triangulationDataSource?: string;
    /**
 * The name of the property from which to extract the Longitude for each item in the ItemsSource.
*/
    longitudeMemberPath?: string;
    /**
     * The name of the property from which to extract the Latitude for each item in the ItemsSource.
    */
    latitudeMemberPath?: string;
    /**
     * The source of triangulation data.
     * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
    */
    trianglesSource?: any[];
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
    */
    triangleVertexMemberPath1?: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
    */
    triangleVertexMemberPath2?: string;
    /**
     * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
    */
    triangleVertexMemberPath3?: string;
}
